# Namestitev programskega paketa

Namestitvene datoteke so objavljene na naslovu [https://prenos.amebis.si/Besana](https://prenos.amebis.si/Besana).

Integriteto prenesenih datotek preverite tako, da poleg prenesene datoteke prenesete še istoimensko datoteko s končnico `.minisig` in v ukazni vrstici uporabite naslednji ukaz:

```bat
minisign -Vm "<ime datoteke>" -P RWRPrtnepBgoU86pKtSnHJXBtmtJjv6T5wN2Q+P7vPgHPdr3v8kGme13
```

Orodje Minisign lahko prenesete na [https://jedisct1.github.io/minisign/](https://jedisct1.github.io/minisign/).

### Windows, MSI

Za namestitev programskega paketa uporabljamo datoteke MSI. Priporočamo prenos datotek MSI na svoj LAN. Programski paket namestimo (ukazna vrstica s skrbniškimi pravicami):

```bat
msiexec /i "\\distsrv\share\Besana.x64.msi" /l* "%TEMP%Besana.x64.log" /qb /norestart
```

`/l* "%TEMP%Besana.x64.log"` v začasno mapo uporabnika, ki izvaja zgornji ukaz, zapiše dnevnik namestitve.
`/qb` pomeni minimalen uporabniški vmesnik, ki ničesar ne sprašuje. Ukazna vrstica počaka na dokončanje namestitve, preden nadaljuje. Ukazu lahko po želji sledi `if errorlevel ...`.
`/norestart` preprečuje samodejni ponovni zagon. Če je potreben ponovni zagon, msiexec konča s kodo 3010. Vendar programski paket ne bo deloval v celoti, dokler uporabnik ponovno ne zažene svojega računalnika.

Z dodatnimi parametri - javnimi spremenljivkami MSI, ki jih dodajamo vedno na konec ukazne vrstice `msiexec` lahko natančneje upravljamo postopek namestitve oz. nadgradnje.

#### Parameter `POSREDNIK=hostname[:port]`

Nastavimo omrežno preverjanje licenc z Amebisovim posrednikom licenc. Kot ime računalnika, na katerega smo namestili Posrednik licenc, lahko navedemo ime računalnika, FQDN, IPv4, [IPv6] (v oglatih oklepajih). Privzeta vrata so 321 (vedno TCP).

```bat
msiexec /i "\\distsrv\share\Besana.x64.msi" /qb POSREDNIK=10.1.1.5
```

#### Parameter `KODALICENCE=nnn-nnn-nnn-nnn-nnn`

Nastavimo lokalno licenco. Kodo licence smo dobili ob nakupu.

```bat
msiexec /i "\\distsrv\share\Besana.x64.msi" /qb KODALICENCE=123-456-789-012-345
```

#### Parametra `PROXYUP=username` in `PROXYGE=password`

Nastavimo uporabniško ime in geslo, če za dostop do spleta HTTP uporabljamo proksi, ki potrebuje avtentikacijo.

```bat
msiexec /i "\\distsrv\share\Besana.x64.msi" /qb PROXYUP=janez PROXYGE="moje geslo 123"
```

Uporabo odsvetujemo! Uporabniško ime in geslo se shranita v register v nekodirani obliki.

### Windows, EXE

Uporabniki, ki ne vedo vnaprej, katere arhitekture je računalnik, lahko uporabijo tudi priloženo datoteko EXE. V datoteki EXE je preprost programček, ki ugotovi arhitekturo. Če je datoteka MSI ustrezne arhitekture na istem imeniku kot datoteka EXE, jo zažene. Sicer pa jo prenese s spleta, preveri digitalni podpis in jo zažene. Nastavljanje parametrov, kot pri ukazu `msiexec` v poglavju [MSI](#windows-msi) trenutno ni podprto.

### macOS

_V pripravi_

# Nastavitev licenciranja

Licenca je vezana na posamezni računalnik.

Programski paket namesti opravilo, ki enkrat na uro poskusi podaljšati licenco za naslednjih (tipično) 30 dni. Zato spremembe v nastavitvah licenc lahko začnejo veljati šele sčasoma.

Programski paket podaljša licenco v naslednjem vrstnem redu po načelu "kar uspe prej":

1. `KodaLicence` - preveri in namesti novo lokalno licenco z dano kodo licence (v nadaljevanju).
2. Obstoječa lokalna licenca - podaljša obstoječo licenco.
3. Obstoječa omrežna licenca - podaljša obstoječo licenco pri istem Posredniku licenc.
4. `Posrednik` - preveri in namesti novo omrežno licenco od danega Posrednika licenc (v nadaljevanju).

Programski paket uporablja licenco v naslednjem vrstnem redu po načelu "katero najde prej in je še veljavna":

1. Lokalna licenca
2. Omrežna licenca

## Lokalna licenca

Lokalno licenco programski paket pridobi od https://licence.amebis.si.

### Windows

Lokalno licenco lahko spremenimo tako, da vpišemo novo kodo licence z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SOFTWARE\Amebis\Besana" /v "KodaLicence" /t REG_SZ /d "123-456-789-012-345" /f /reg:64
"C:\Program Files\Amebis Besana\ALicVL.exe"
```

Lokalna licenca je shranjena v registru `HKEY_LOCAL_MACHINE\\SOFTWARE\\Amebis\\Besana\\Licenca`. Odstranimo jo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg delete "HKLM\SOFTWARE\Amebis\Besana\Licenca" /f /reg:64
```

### macOS

Lokalno licenco lahko spremenimo tako, da vpišemo novo kodo licence z ukazom:

```sh
sudo defaults write /Library/Application\ Support/Amebis/Besana.plist KodaLicence -string 123-456-789-012-345
sudo chmod a+r /Library/Application\ Support/Amebis/Besana.plist
/Applications/Amebis\ Besana/ALicVL
```

Lokalna licenca je shranjena v `/Library/Application\ Support/Amebis/Besana/Licenca.plist`. Odstranimo jo z ukazom:

```sh
sudo rm /Library/Application\ Support/Amebis/Besana/Licenca.plist
```

## Omrežna licenca

Omrežno licenco programski paket pridobi od Amebisovega posrednika licenc. Računalnik, na katerem imamo nameščen Posrednik licenc, nastavimo ob namestitvi ali v registru. Osveževalnik bo vedno najprej poskušal podaljšati licenco pri istem posredniku, kot jo je dobil uvodoma.

### Windows

Posrednik nastavimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SOFTWARE\Amebis\Besana" /v "Posrednik" /t REG_SZ /d "10.1.1.5" /f /reg:64
"C:\Program Files\Amebis Besana\ALicVL.exe"
```

ali:

```bat
reg add "HKEY_LOCAL_MACHINE\SOFTWARE\Amebis\Besana" /v "Posrednik" /t REG_MULTI_SZ /d "alicpos.lj.org.home\0alicpos.mb.org.home" /f /reg:64
"C:\Program Files\Amebis Besana\ALicVL.exe"
```

Omrežna licenca je shranjena v registru `HKEY_LOCAL_MACHINE\\SOFTWARE\\Amebis\\Besana\\Posredno`. Odstranimo jo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg delete "HKLM\SOFTWARE\Amebis\Besana\Posredno" /f /reg:64
```

### macOS

Posrednik nastavimo z ukazom:

```sh
sudo defaults write /Library/Application\ Support/Amebis/Besana.plist Posrednik -array -string 10.1.1.5
sudo chmod a+r /Library/Application\ Support/Amebis/Besana.plist
/Applications/Amebis\ Besana/ALicVL
```

ali:

```sh
sudo defaults write /Library/Application\ Support/Amebis/Besana.plist Posrednik -array -string alicpos.lj.org.home -string alicpos.mb.org.home
sudo chmod a+r /Library/Application\ Support/Amebis/Besana.plist
/Applications/Amebis\ Besana/ALicVL
```

Omrežna licenca je shranjena v `/Library/Application\ Support/Amebis/Besana/Posredno.plist`. Odstranimo jo z ukazom:

```sh
sudo rm /Library/Application\ Support/Amebis/Besana/Posredno.plist
```

# Pravopisni strežnik Amebis Besana

Pravopisni strežnik BesStr je sistemski servis Windows oz. servis `launchd` na macOS, ki ponuja preverjanje pravopisa in črkovanja besed preko protokola HTTP. Za komunikacijo uporablja protokol HTTP. Vgrajen ima lasten strežnik HTTP in ne potrebuje storitve Internet Information Services.

Je sestavni del programskega paketa Amebis Besana od verzije 4.15 dalje. Prvotno je bil namenjen podpori vtičnikom LanguageTool za spletne brskalnike. Kasneje je bil razširjen za splošnejšo rabo. Uporablja ga tudi aplikacija Besana.

Namestitev programskega paketa nastavi servis za samodejni zagon in ga požene.

Pri vsakem spreminjanju nastavitev v registru oz. datotekah `.plist` moramo servis ponovno zagnati, saj prebere nastavitve samo ob svojem zagonu.

Morebitna obvestila in napake servis zapisuje v Event Log (Windows) oz. v Console (macOS).

## Vtičnica TCP za sprejemanje zahtev

Strežnik privzeto sprejema zahteve na `localhost:225` - IPv4 in IPv6, TCP, HTTP.

Lahko navedemo svoj spisek vtičnic, na katerih želimo, da strežnik sprejema zahteve. Vtičnice so lahko naslov IPv4, naslov IPv6 (obdan z oglatimi oklepaji, npr. [::1]), ime računalnika ali FQDN. Vtičnici lahko pripišemo dvopičje in številko vrat TCP, kadar želimo, da strežnik sprejema odjemalce na drugih vratih TCP, kot privzeto TCP 225.

### TLS

_V pripravi_

### Windows

Spisek vtičnic nastavimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\BesStr\Parametri" /v "Sprejemaj" /t REG_MULTI_SZ /d "0.0.0.0:80\0[::]:80" /f /reg:64
net stop BesStr
net start BesStr
```

### macOS

Spisek vtičnic nastavimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/BesStr.plist" "Sprejemaj" -array -string "0.0.0.0:225" -string "[::]:225"
sudo chmod a+r "/Library/Application Support/Amebis/Besana/BesStr.plist"
sudo launchctl unload /System/Library/LaunchDaemons/BesStr.plist
sudo launchctl load /System/Library/LaunchDaemons/BesStr.plist
```

## Beleženje zahtev v datoteko

Strežnik privzeto ne beleži zahtev. Lahko pa za diagnostične potrebe vklopimo beleženje zahtev HTTP v datoteko.

### Windows

Beleženje zahtev v datoteko nastavimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\BesStr\Parametri" /v "DatotekaDnevnika" /t REG_EXPAND_SZ /d "%TEMP%\BesStr.log" /f /reg:64
net stop BesStr
net start BesStr
```

### macOS

Beleženje zahtev v datoteko nastavimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/BesStr.plist" "DatotekaDnevnika" -string "/tmp/BesStr.log"
sudo chmod a+r "/Library/Application Support/Amebis/Besana/BesStr.plist"
sudo launchctl unload /System/Library/LaunchDaemons/BesStr.plist
sudo launchctl load /System/Library/LaunchDaemons/BesStr.plist
```

<!---
## Zaledni strežnik LanguageTool

Strežnik BesStr nudi jezikovne storitve samo za slovenščino. Kadar vtičnik LanguageTool navede jezik besedila kot `auto`, strežnik najprej poskusi določiti jezik besedila. Če jezik ni slovenski, privzeto posreduje zahtevo Amebisovemu strežniku LanguageTool. To omogoča preverjanje tudi ne-slovenskih besedil, a uporabnikova besedila zapustijo uporabnikov računalnik ([politika zasebnosti](https://besana.amebis.si/pravno_obvestilo/)).

### Windows

Uporabo zalednega strežnika izklopimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\BesStr\Parametri" /v "LanguageToolStreznik" /t REG_SZ /d "" /f /reg:64
net stop BesStr
net start BesStr
```

Uporabo svojega zalednega strežnika LanguageTool lahko nastavimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\BesStr\Parametri" /v "LanguageToolStreznik" /t REG_SZ /d "http://localhost:8080/" /f /reg:64
net stop BesStr
net start BesStr
```

### macOS

Uporabo svojega zalednega strežnika LanguageTool lahko nastavimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/BesStr.plist" "LanguageToolStreznik" -string ""
sudo chmod a+r "/Library/Application Support/Amebis/Besana/BesStr.plist"
sudo launchctl unload /System/Library/LaunchDaemons/BesStr.plist
sudo launchctl load /System/Library/LaunchDaemons/BesStr.plist
```

Uporabo svojega zalednega strežnika LanguageTool lahko nastavimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/BesStr.plist" "LanguageToolStreznik" -string "http://localhost:8080/"
sudo chmod a+r "/Library/Application Support/Amebis/Besana/BesStr.plist"
sudo launchctl unload /System/Library/LaunchDaemons/BesStr.plist
sudo launchctl load /System/Library/LaunchDaemons/BesStr.plist
```
-->

## Slovar v glavnem pomnilniku

Besana lahko ob zagonu naloži slovar `.apz` v glavni pomnilnik. Poraba pomnilnika je sicer ustrezno večja in zagon počasnejši, a je preverjanje pravopisa potem hitrejše. Kadar je Besana nameščena na pogonu HDD, bo hitrost preverjanja pravopisa za velikostni razred večja. Na pogonih SSD je razlika v hitrosti še vedno opazna.

Zato to možnost svetujemo na vseh računalnikih z dovolj delovnega pomnilnika.

### Windows

Nalaganje slovarja v glavni pomnilnik vklopimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SOFTWARE\Amebis\Besana\AJTOdj" /v "SlovarVPomnilniku" /t REG_DWORD /d 1 /f /reg:64
net stop BesStr
net start BesStr
```

Nalaganje slovarja v glavni pomnilnik izklopimo z ukazom (ukazna vrstica s skrbniškimi pravicami):

```bat
reg add "HKEY_LOCAL_MACHINE\SOFTWARE\Amebis\Besana\AJTOdj" /v "SlovarVPomnilniku" /t REG_DWORD /d 0 /f /reg:64
net stop BesStr
net start BesStr
```

### macOS

Nalaganje slovarja v glavni pomnilnik vklopimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/AJTOdj.plist" "SlovarVPomnilniku" -bool True
sudo chmod a+r "/Library/Application Support/Amebis/Besana/AJTOdj.plist"
sudo launchctl unload /System/Library/LaunchDaemons/AJTOdj.plist
sudo launchctl load /System/Library/LaunchDaemons/AJTOdj.plist
```

Nalaganje slovarja v glavni pomnilnik izklopimo z ukazom:

```sh
sudo defaults write "/Library/Application Support/Amebis/Besana/AJTOdj.plist" "SlovarVPomnilniku" -bool False
sudo chmod a+r "/Library/Application Support/Amebis/Besana/AJTOdj.plist"
sudo launchctl unload /System/Library/LaunchDaemons/AJTOdj.plist
sudo launchctl load /System/Library/LaunchDaemons/AJTOdj.plist
```
